@@ -91,8 +91,8 @@ class Products extends CGExtensions
 
   function GetDependencies()
   {
-	return array('CGExtensions'=>'1.21',
-		     'CGSimpleSmarty'=>'1.4.4');
+	return array('CGExtensions'=>'1.23',
+				 'CGSimpleSmarty'=>'1.4.4');
   }
 
   function AllowAutoInstall()
@@ -117,12 +117,12 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.9.2';
+	return '2.10.2';
   }
 
   function MinimumCMSVersion()
   {
-	return '1.8.2';
+	return '1.9.1';
   }
 
   function GetAdminDescription()
@@ -223,14 +223,17 @@ EOT;
 	$this->SetParameterType('alias',CLEAN_STRING);
 	$this->SetParameterType('hierarchyid',CLEAN_INT);
 	$this->SetParameterType('categoryid',CLEAN_INT);
+
+	$this->CreateParameter('productlist',$this->Lang('param_productlist'));
+	$this->SetParameterType('productlist',CLEAN_NONE);
+
 	$this->SetParameterType(CLEAN_REGEXP.'/cd_.*/',CLEAN_STRING);
 
 	// Friendly URL stuff
     $detailpage = $this->GetPreference('detailpage',-1);
+	$contentops = cmsms()->GetContentOperations();
     if( $detailpage == -1 )
       {
-		global $gCms;
-		$contentops =& $gCms->GetContentOperations();
 		$detailpage = $contentops->GetDefaultPageID();
       }
 	$str = '/'.$this->GetPreference('urlprefix','[Pp]roducts');
@@ -255,9 +258,16 @@ EOT;
 	$this->RegisterRoute($str.'\/bycategory\/(?P<categoryid>[0-9]+)\/(?P<returnid>[0-9]+)$/');
 	$this->RegisterRoute($str.'\/byhierarchy\/(?P<hierarchyid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/');
 	$this->RegisterRoute($str.'\/byhierarchy\/(?P<hierarchyid>[0-9]+)\/(?P<returnid>[0-9]+)$/');
+
+	$hierpage = $this->GetPreference('hierpage',-1);
+	if( $hierpage <= 0 )
+	  {
+		$hierpage = $detailpage;
+	  }
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<returnid>[0-9]+)$/');
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/');
-
+	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<junk>.*?)$/',
+						 array('action'=>'hierarchy','returnid'=>$hierpage));
   }
 
   function InstallPostMessage()
@@ -866,9 +876,23 @@ EOT;
 		break;
 
 	  case 'hierarchy':
-		$prettyurl = sprintf("%s/hierarchy/%d/%d",
+		$prettyurl = sprintf('%s/hierarchy/%d',
 							 $this->GetPreference('urlprefix','products'),
-							 (int)$params['parent'],$returnid);
+							 (int)$params['parent']);
+		if( $this->GetPreference('hierpage',-1) == -1 )
+		  {
+			// use returnid in the link.
+			$prettyurl .= '/'.$returnid;
+		  }
+		if( $this->GetPreference('prettyhierurls',0) )
+		  {
+			// add the name to the url.
+			$info = hierarchy_ops::get_hierarchy_info($params['parent']);
+			if( is_array($info) )
+			  {
+				$prettyurl .= '/'.munge_string_to_url($info['name']);
+			  }
+		  }
 		break;
 
 	  }
