@@ -52,6 +52,13 @@ $fieldefs = '';
     }
 }
 
+$query = '';
+$query2 = '';
+$count = '';
+$page = '';
+$startelement = '';
+$limit = 99999;
+$productlist = '';
 $sorttype = '';
 $countjoins = array();
 $joins = array();
@@ -97,277 +104,305 @@ if( isset($params['summarytemplate'] ) )
   }
 
 
-$sortorder = $this->GetPreference('sortorder','asc');
-if( isset( $params['sortorder'] ) )
+if( isset($params['productlist']) )
   {
+    $productlist = $params['productlist'];
+    unset($params['productlist']);
+    if( !is_array($productlist) )
+      {
+	$productlist = explode(',',$productlist);
+      }
+  }
+if( !(is_array($productlist) && count($productlist) > 0) )
+  {
+    // we don't have an explicit product list, so gotta build a query
+    // from other parameters
+    $sortorder = $this->GetPreference('sortorder','asc');
+    if( isset( $params['sortorder'] ) )
+      {
 	switch( $params['sortorder'] )
 	  {
 	  case 'asc':
 	  case 'desc':
-		$sortorder = $params['sortorder'];
+	    $sortorder = $params['sortorder'];
 	  }
-  }
-
-$sortby = $this->GetPreference('sortby','product_name');
-if( isset( $params['sortby'] ) )
-  {
-    $tmp = strtolower(trim($params['sortby']));
-    switch( $tmp )
+      }
+    
+    $sortby = $this->GetPreference('sortby','product_name');
+    if( isset( $params['sortby'] ) )
       {
-      case 'id':
-	$sortby = 'id';
-	break;
+	$tmp = strtolower(trim($params['sortby']));
+	switch( $tmp )
+	  {
+	  case 'id':
+	    $sortby = 'id';
+	    break;
 	
-      case 'product_name':
-	$sortby = 'product_name';
-	break;
-      case 'price':
-	$sortby = 'price';
-	break;
-      case 'created':
-	$sortby = 'create_date';
-	break;
-      case 'modified':
-	$sortby = 'modified_date';
-	break;
-      case 'status':
-	$sortby = 'status';
-	break;
-      case 'weight':
-	$sortby = 'weight';
-	break;
-      case 'random':
+	  case 'product_name':
+	    $sortby = 'product_name';
+	    break;
+	  case 'price':
+	    $sortby = 'price';
+	    break;
+	  case 'created':
+	    $sortby = 'create_date';
+	    break;
+	  case 'modified':
+	    $sortby = 'modified_date';
+	    break;
+	  case 'status':
+	    $sortby = 'status';
+	    break;
+	  case 'weight':
+	    $sortby = 'weight';
+	    break;
+	  case 'random':
+	    $sortby = 'RAND()';
+	    $sortorder = '';
+	    break;
+	  default:
+	    if( startswith($tmp,'f:') )
+	      {
+		$fieldname = substr($tmp,strlen('f:'));
+		if( isset($fielddefs[$fieldname]) )
+		  {
+		    $fieldid = $fielddefs[$fieldname]->id;
+		    $as = 'FV'.$sortfield++;
+		    $joins[] = cms_db_prefix()."module_products_fieldvals {$as} ON c.id = {$as}.product_id AND $as.fielddef_id = '{$fieldid}'";
+		    $sortby = "{$as}.value";
+		  }
+	      }
+	    break;
+	  }
+      }
+    if( $sortby == 'random' )
+      {
 	$sortby = 'RAND()';
 	$sortorder = '';
-	break;
-      default:
-	if( startswith($tmp,'f:') )
+      }
+
+    if( isset($params['sorttype']) )
+      {
+	$tmp = trim($params['sorttype']);
+	$tmp = strtoupper($tmp);
+	switch( $tmp )
 	  {
-	    $fieldname = substr($tmp,strlen('f:'));
-	    if( isset($fielddefs[$fieldname]) )
-	      {
-		$fieldid = $fielddefs[$fieldname]->id;
-		$as = 'FV'.$sortfield++;
-		$joins[] = cms_db_prefix()."module_products_fieldvals {$as} ON c.id = {$as}.product_id AND $as.fielddef_id = '{$fieldid}'";
-		$sortby = "{$as}.value";
-	      }
+	  case 'STRING':
+	    $sorttype = '';
+	    break;
+	  case 'SIGNED':
+	  case 'UNSIGNED':
+	    $sorttype = $tmp;
 	  }
-	break;
       }
-  }
-if( $sortby == 'random' )
-  {
-    $sortby = 'RAND()';
-    $sortorder = '';
-  }
-
-if( isset($params['sorttype']) )
-  {
-    $tmp = trim($params['sorttype']);
-    $tmp = strtoupper($tmp);
-    switch( $tmp )
+    $limit = $this->GetPreference('summary_pagelimit',10000);
+    if( isset($params['pagelimit']) )
       {
-      case 'STRING':
-	$sorttype = '';
-	break;
-      case 'SIGNED':
-      case 'UNSIGNED':
-	$sorttype = $tmp;
+	$limit = (int)$params['pagelimit'];
       }
-  }
-$limit = $this->GetPreference('summary_pagelimit',10000);
-if( isset($params['pagelimit']) )
-  {
-    $limit = (int)$params['pagelimit'];
-  }
-$limit = max($limit,1);
-$limit = min($limit,10000);
+    $limit = max($limit,1);
+    $limit = min($limit,10000);
 
-$page = 1;
-if( isset($params['page']) )
-  {
-    $page = (int)$params['page'];
-    if( $page < 1 ) $page = 1;
-  }
-$startelement = ($page-1)*$limit;
-
-$category = '';
-$inputcat = '';
-if( isset( $params['category'] ) )
-  {
-    $category = trim($params['category']);
-    $category = cms_html_entity_decode($category);
-  }
-else if (isset($params['categoryid']))
-  {
-    $categoryid = $params['categoryid'];
-  }
-
-$hierarchy = '';
-if( isset( $params['hierarchy'] ) )
-  {
-    $hierarchy = trim($params['hierarchy']);
-  }
-$hierarchyid = -100;
-if( isset($params['hierarchyid']) )
-  {
-    $hierarchyid = (int)$params['hierarchyid'];
-  }
-
-$fieldid = -100;
-if( isset( $params['fieldid']) )
-  {
-    $fieldid = (int)$params['fieldid'];
-  }
-$fieldval = '';
-if( isset( $params['fieldval'] ) )
-  {
-    $fieldval = trim($params['fieldval']);
-  }
-
-
-//
-// Build the pretty urls
-//
-
-//
-// Build the queries
-//
-$entryarray = array();
-$paramarray = array();
-$where = array();
-$query = "SELECT c.* FROM ".cms_db_prefix()."module_products c";
-$query2 = "SELECT count(*) as count FROM ".cms_db_prefix()."module_products c";
-$where[] = 'c.status = \'published\'';
-if ( isset($categoryid) && $categoryid != '')
-{
-  $str = " INNER JOIN ".cms_db_prefix()."module_products_product_categories cc ON cc.product_id = c.id";
-  $query .= $str;
-  $query2 .= $str;
-  $where[] = 'cc.category_id = ?';
-  $paramarray[] = $categoryid;
-}
-else if( isset($category) && $category != '' )
-{
-  $str = " INNER JOIN ".cms_db_prefix()."module_products_product_categories cc ON cc.product_id = c.id";
-  $query .= $str;
-  $query2 .= $str;
-  $str = " INNER JOIN ".cms_db_prefix()."module_products_categories cs ON cs.id = cc.category_id";
-  $query .= $str;
-  $query2 .= $str;
-
-  $arr1 = explode(',',$category);
-  $arr2 = array();
-  foreach( $arr1 as $xx )
-	{
-	  $arr2[] = "'".$xx."'";
-	}
-  $txt = implode(',',$arr2);
-  $where[] = 'cs.name IN ('.$txt.')';
-}
-
-if ( isset($hierarchy) && $hierarchy != '' )
-  {
-    $str = " INNER JOIN ".cms_db_prefix()."module_products_prodtohier ph ON ph.product_id = c.id";
-    $query .= $str;
-    $query2 .= $str;
-
-    $str = " INNER JOIN ".cms_db_prefix()."module_products_hierarchy h ON ph.hierarchy_id = h.id";
-    $query .= $str;
-    $query2 .= $str;
-
-    $tmp2 = array();
-    $tmp = explode(',',$hierarchy);
-    foreach( $tmp as $one )
+    $page = 1;
+    if( isset($params['page']) )
       {
-	if( strstr($one,'*') !== FALSE )
+	$page = (int)$params['page'];
+	if( $page < 1 ) $page = 1;
+      }
+    $startelement = ($page-1)*$limit;
+
+    $category = '';
+    $inputcat = '';
+    if( isset( $params['category'] ) )
+      {
+	$category = trim($params['category']);
+	$category = cms_html_entity_decode($category);
+      }
+    else if (isset($params['categoryid']))
+      {
+	$categoryid = $params['categoryid'];
+      }
+
+    $hierarchy = '';
+    if( isset( $params['hierarchy'] ) )
+      {
+	$hierarchy = trim($params['hierarchy']);
+      }
+    $hierarchyid = -100;
+    if( isset($params['hierarchyid']) )
+      {
+	$hierarchyid = (int)$params['hierarchyid'];
+      }
+
+    $fieldid = -100;
+    if( isset( $params['fieldid']) )
+      {
+	$fieldid = (int)$params['fieldid'];
+      }
+    $fieldval = '';
+    if( isset( $params['fieldval'] ) )
+      {
+	$fieldval = trim($params['fieldval']);
+      }
+
+
+    //
+    // Build the queries
+    //
+    $entryarray = array();
+    $paramarray = array();
+    $where = array();
+    $query = "SELECT c.* FROM ".cms_db_prefix()."module_products c";
+    $query2 = "SELECT count(*) as count FROM ".cms_db_prefix()."module_products c";
+    $where[] = 'c.status = \'published\'';
+    if ( isset($categoryid) && $categoryid != '')
+      {
+	$str = " INNER JOIN ".cms_db_prefix()."module_products_product_categories cc ON cc.product_id = c.id";
+	$query .= $str;
+	$query2 .= $str;
+	$where[] = 'cc.category_id = ?';
+	$paramarray[] = $categoryid;
+      }
+    else if( isset($category) && $category != '' )
+      {
+	$str = " INNER JOIN ".cms_db_prefix()."module_products_product_categories cc ON cc.product_id = c.id";
+	$query .= $str;
+	$query2 .= $str;
+	$str = " INNER JOIN ".cms_db_prefix()."module_products_categories cs ON cs.id = cc.category_id";
+	$query .= $str;
+	$query2 .= $str;
+
+	$arr1 = explode(',',$category);
+	$arr2 = array();
+	foreach( $arr1 as $xx )
 	  {
-	    $tmp2[] = "upper(h.long_name) LIKE upper(?)";
+	    $arr2[] = "'".$xx."'";
+	  }
+	$txt = implode(',',$arr2);
+	$where[] = 'cs.name IN ('.$txt.')';
+      }
+
+    if ( isset($hierarchy) && $hierarchy != '' )
+      {
+	$str = " INNER JOIN ".cms_db_prefix()."module_products_prodtohier ph ON ph.product_id = c.id";
+	$query .= $str;
+	$query2 .= $str;
+
+	$str = " INNER JOIN ".cms_db_prefix()."module_products_hierarchy h ON ph.hierarchy_id = h.id";
+	$query .= $str;
+	$query2 .= $str;
+
+	$tmp2 = array();
+	$tmp = explode(',',$hierarchy);
+	foreach( $tmp as $one )
+	  {
+	    if( strstr($one,'*') !== FALSE )
+	      {
+		$tmp2[] = "upper(h.long_name) LIKE upper(?)";
+	      }
+	    else
+	      {
+		$tmp2[] = "upper(h.name) = upper(?)";
+	      }
+
+	    $one = cms_html_entity_decode($one);
+	    $one = trim(str_replace('*','%',str_replace('"','_',$one)));
+	    $paramarray[] = $one;
+	  }
+	$str = '(' . implode(' OR ',$tmp2) . ')';
+	$where[] = $str;
+      }
+    else if( $hierarchyid > -100 )
+      {
+	$str = " INNER JOIN ".cms_db_prefix()."module_products_prodtohier ph ON ph.product_id = c.id";
+	$query .= $str;
+	$query2 .= $str;
+
+	$where[] = "ph.hierarchy_id = ?";
+	$paramarray[] = $hierarchyid;
+      }
+
+    if( isset($fieldid) && $fieldid > 0 && isset($fieldval) && !empty($fieldval) )
+      {
+	// handle gathering products that have a certain field id.
+	if( $fieldval == '::null::' )
+	  {
+	    // handle a case when a field is not set for a product.
+	    $countjoins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
+	    $joins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
+	    $where[] = '(FVA.value IS NULL)';
+	    array_unshift($paramarray,$fieldid);
+	    //$paramarray[] = $fieldid;
+	  }
+	if( $fieldval == '::notnull::' )
+	  {
+	    // handle a case when a field is not set for a product.
+	    $countjoins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
+	    $joins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
+	    $where[] = '(FVA.value != \'\')';
+	    array_unshift($paramarray,$fieldid);
 	  }
 	else
 	  {
-	    $tmp2[] = "upper(h.name) = upper(?)";
+	    // limit results to all of the items that have this field value.
+	    $countjoins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
+	    $joins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
+	    $where[] = 'FVA.value = ?';
+	    array_unshift($paramarray,$fieldid);
+	    //$paramarray[] = $fieldid;
+	    $paramarray[] = $fieldval;
 	  }
 
-	$one = cms_html_entity_decode($one);
-	$one = trim(str_replace('*','%',str_replace('"','_',$one)));
-	$paramarray[] = $one;
+	if( count($joins) )
+	  {
+	    $query .= ' LEFT JOIN '.implode(' LEFT JOIN ',$joins);
+	  }
+	if( count($countjoins) )
+	  {
+	    $query2 .= ' LEFT JOIN '.implode(' LEFT JOIN ',$countjoins);
+	  }
+	$query = $query . ' WHERE ' . implode(' AND ',$where );
+	$query2 = $query2 . ' WHERE ' . implode(' AND ',$where );
+	if( $sorttype == '' )
+	  {
+	    $query .= " ORDER BY ".$sortby." ".$sortorder;
+	  }
+	else
+	  {
+	    $query .= ' ORDER BY CAST('.$sortby.' AS '.$sorttype.') '.$sortorder;
+	  }
       }
-    $str = '(' . implode(' OR ',$tmp2) . ')';
-    $where[] = $str;
-  }
-else if( $hierarchyid > -100 )
-  {
-    $str = " INNER JOIN ".cms_db_prefix()."module_products_prodtohier ph ON ph.product_id = c.id";
-    $query .= $str;
-    $query2 .= $str;
 
-    $where[] = "ph.hierarchy_id = ?";
-    $paramarray[] = $hierarchyid;
-  }
-
-if( isset($fieldid) && $fieldid > 0 && isset($fieldval) && !empty($fieldval) )
-  {
-    // handle gathering products that have a certain field id.
-    if( $fieldval == '::null::' )
+    // Execute the Queries
+    $count = $db->GetOne($query2,$paramarray);
+    if( $count == 0 ) return;
+    $dbresult = $db->SelectLimit($query, $limit, $startelement, $paramarray);
+    if( !$dbresult ) 
       {
-	// handle a case when a field is not set for a product.
-	$countjoins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
-	$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
-	$where[] = '(FVA.value IS NULL)';
-        array_unshift($paramarray,$fieldid);
-	//$paramarray[] = $fieldid;
+	echo $db->sql.'<br/>'; die( $db->ErrorMsg() );
       }
-    if( $fieldval == '::notnull::' )
-      {
-	// handle a case when a field is not set for a product.
-	$countjoins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
-	$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
-	$where[] = '(FVA.value != \'\')';
-        array_unshift($paramarray,$fieldid);
-      }
-    else
-      {
-	// limit results to all of the items that have this field value.
-	$countjoins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
-	$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON c.id = FVA.product_id AND FVA.fielddef_id = ?';
-        $where[] = 'FVA.value = ?';
-        array_unshift($paramarray,$fieldid);
-	//$paramarray[] = $fieldid;
-	$paramarray[] = $fieldval;
-      }
-  }
 
-
-if( count($joins) )
-  {
-    $query .= ' LEFT JOIN '.implode(' LEFT JOIN ',$joins);
-  }
-if( count($countjoins) )
-  {
-    $query2 .= ' LEFT JOIN '.implode(' LEFT JOIN ',$countjoins);
-  }
-$query = $query . ' WHERE ' . implode(' AND ',$where );
-$query2 = $query2 . ' WHERE ' . implode(' AND ',$where );
-if( $sorttype == '' )
-  {
-    $query .= " ORDER BY ".$sortby." ".$sortorder;
-  }
+  } // end product list not specified.
 else
   {
-    $query .= ' ORDER BY CAST('.$sortby.' AS '.$sorttype.') '.$sortorder;
+    // a product id list was specified
+    // which means we display only the products specified.
+    $count = count($productlist);
+    $query = 'SELECT * FROM '.cms_db_prefix().'module_products WHERE id IN (';
+    
+    // clean up the productlist, just in case
+    $productlist = array_unique($productlist);
+    for( $i = 0; $i < count($productlist); $i++ )
+      {
+	$productlist[$i] = (int)$productlist[$i];
+      }
+    $query .= implode(',',$productlist).')';
+    
+    $dbresult = $db->SelectLimit($query,1000,0);
   }
 
 
 
-// Execute the Queries
-$count = $db->GetOne($query2,$paramarray);
-if( $count == 0 ) return;
-$dbresult = $db->SelectLimit($query, $limit, $startelement, $paramarray);
-if( !$dbresult ) 
-  {
-    echo $db->sql.'<br/>'; die( $db->ErrorMsg() );
-  }
 
 // Determine the number of pages
 $npages = intval($count / $limit);
