@@ -92,7 +92,7 @@ else if( isset($params['test']) )
     $error = '';
     $messages = array();
     $import_errors = array();
-    $config =& $gCms->GetConfig();
+    $config = $gCms->GetConfig();
     $uh = new cg_fileupload($id,$config['root_path'].'/tmp/cache');
     $uh->set_accepted_filetypes('csv');
     $uh->set_allow_overwrite();
