@@ -769,8 +769,6 @@ class productsCsvImporter
     // according to the header.
     if( $this->_getFieldCount() != $this->_getDefCount() )
       {
-	debug_display($this->_defs_byindex);
-	debug_display($this->_record); die();
 	$this->_setError('invalid field count ('.$this->_getFieldCount().' of expected '.$this->_getDefCount().')');
 	return FALSE;
       }
