@@ -49,7 +49,7 @@ while( $dbr && ($row = $dbr->FetchRow()) )
     $row['edit_url'] = $this->CreateURL($id,'admin_edit_hierarchy_item',
 					$returnid,
 					array('hierarchy_id'=>$row['id']));
-    $row['depth'] = count(split('\.', $row['hierarchy'])) - 1;
+    $row['depth'] = count(explode('\.', $row['hierarchy'])) - 1;
     $row['edit_link'] = $this->CreateImageLink($id,'admin_edit_hierarchy_item',
 					       $returnid,
 					       $this->Lang('edit_hierarchy_item'),
