@@ -210,6 +210,7 @@ Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p
 EOT;
 $lang['hierarchy']  = 'Hierarchy';
 $lang['hierarchy_position'] = 'Hierarchy Position';
+$lang['hierarchy_settings'] = 'Hierarchy Settings';
 
 # I
 $lang['id'] = 'Id';
@@ -234,8 +235,10 @@ $lang['info_duplicateproducts'] = 'Specify how the system should handle a produc
 $lang['info_fielddefs_tab'] = '<strong>Note: </strong> All Fields defined here are available to all products.';
 $lang['info_fieldproblems'] = 'Problems were encountered when dealing with one or more custom fields.  The action has completed successfully, however you should investigate and correct these problems';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
+$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
 $lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
 $lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
+$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Valid values are +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Public fields are available for the public to see';
@@ -302,6 +305,7 @@ $lang['param_inline'] = 'Useful only with the search action, this parameter spec
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> or search actions, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
 $lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what product to use for the display.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
@@ -385,6 +389,8 @@ $lang['prompt_notfound_301'] = 'Generate a 301 redirect';
 $lang['prompt_notfound_errormsg'] = 'Display an error message';
 $lang['prompt_notfound_msg'] = 'Error message for when a product cannot be found';
 $lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
+$lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
+$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
 $lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
 $lang['prompt_products_matching'] = 'Products matching %s';
 $lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
