@@ -246,14 +246,14 @@ $lang['param_action'] = 'Specify the behaviour of the module.  Possible values a
   </li>
   <li>search - Display a form to allow searching products on various criterium</li>
 </ul>';
-$lang['param_category'] = 'N&aring;r benyttet med <em>standard</em> sammendragsmodus vil denne parameter, som skal v&aelig;re lik navnet p&aring; en eksisterende kategori, bli benyttet for &aring; vise kun de produktene som er i denne kategorien. (en kommaseparert liste kan oppgis)';
+$lang['param_category'] = 'N&aring;r benyttet med <em>standard</em> sammendragsmodus vil denne parameter, som skal v&aelig;re lik navnet p&aring; en eksisterende kategori, bli benyttet for &aring; vise kun de produktene som er i denne kategorien. (en kommaseparert liste kan oppgis) Denne parameteren kan ogs&aring; benyttes med categorylist handlingen for &aring; begrense utdata til de spesifiserte produktkatagoriene.';
 $lang['param_categorylisttemplate'] = 'Med kategoriliste  og fieldlist handlingene, vil denne parameter indikere malen som skal benyttes for visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet.';
 $lang['param_categorylistdtltemplate'] = 'Kan kun benyttes med categorylist handlingene, hvor denne parameteren indikerer malen som skal benyttes for visning av kategoridetaljer. Dette benytter en katagorilistemal.. Om ingen verdi er spesifisert s&aring; vil n&aring;v&aelig;rende standardmal av denne typen bli benyttet.';
 $lang['param_detailpage'] = 'Dette spesifiserer sideid&#039;en eller sidealias som skal benyttes for &aring; vise detaljrapporten. Dette kan benyttes med <em>default</em> eller s&oslash;k handlingene.';
 $lang['param_detailtemplate'] = 'Denne parameter spesifiserer malen som skal benyttes for detaljmodus visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet. Denne parameter har ingen virkning n&aring;r vakre urler er p&aring;sl&aring;tt.';
 $lang['param_field'] = 'Benyttet kun i <em>fieldlist</em> handlingen, der denne parameter er p&aring;krevd for &aring; spesifisere navnet p&aring; en brukerdefinert egenskap som det skal lages en liste fra.';
 $lang['param_fieldval'] = 'Kun benyttet i <em>standard</em> handlinge, hvor denne parameter tillater &aring; spesifisere en feltverdi &aring; begrense resultater etter. Spesialverdier for dette feltet er &quot;::null::&quot; &quot;::notnull::&quot;';
-$lang['param_hierarchy'] = 'Kan kun benyttes i <em>default</em> handlingen. Denne parameter spesifiserer at kun artikler i denne lokasjonen i hierarkiet skal vises.  Jokertegn kan benyttes s&aring; du ogs&aring; kan spesifisere foreldre/barn relasjoner. F.eks. {Products hierarchy=&#039;trucks*&#039;} vil lage en sammendragsrapport med alle trucks, inkludert barna i hierarkiet.  P&aring; samme m&aring;te, {Products hierarchy=&#039;*trucks&#039;} vil vise en sammendragsrapport med alle trucks og alle produkter tilh&oslash;rende enhver foreldre i hierarkiet.';
+$lang['param_hierarchy'] = 'Kan kun benyttes i <em>default</em> og hierarki handlinger. Denne parameter har to oppgaver - den spesifiserer at kun artikler i denne lokasjonen i hierarkiet skal vises.  Jokertegn kan benyttes s&aring; du ogs&aring; kan spesifisere foreldre/barn relasjoner. F.eks. {Products hierarchy=&#039;trucks*&#039;} vil lage en sammendragsrapport med alle trucks, inkludert barna i hierarkiet.  P&aring; samme m&aring;te, {Products hierarchy=&#039;*trucks&#039;} vil vise en sammendragsrapport med alle trucks og alle produkter tilh&oslash;rende enhver foreldre i hierarkiet. N&aring;r benyttet med hierarkihandlingen s&aring; kan denne parameter gi en liste med hierarkinavn for &aring; vise akkurat disse. F.eks. {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;}';
 $lang['param_hierarchytemplate'] = 'Denne parameter spesifiserer malen som skal brukes for hierarki visning. Om ingen verdi er satt vil standard mal av den typen bli benyttet.';
 $lang['param_inline'] = 'Kun nyttig for s&oslash;k-handlingen, der denne parameteren spesifiserer at utdata for sammendragesvisningen skal vises inline';
 $lang['param_pagelimit'] = 'Benyttet med <em>standard</em> handlingen vil denne parameter spesifisere hvor mange produkter som skal listes p&aring; hver side.';
@@ -268,7 +268,7 @@ $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.
   <li><strong>asc</strong> -- Ascending order</li>
   <li>desc -- Descending order</li>
 </ul>';
-$lang['param_sortby'] = 'Applicable only in summary mode, this parameter determines the sorting of the output products.  Possible values are:
+$lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
 <ul>
   <li><strong>product_name</strong></li>
   <li>id -- The product id</li>
@@ -279,6 +279,11 @@ $lang['param_sortby'] = 'Applicable only in summary mode, this parameter determi
   <li>created -- The creation date for this company record</li>
   <li>modified -- The modified date for this company record</li>
   <li>f:fieldname -- Allows sorting by values of custom fields.</li>
+</ul>
+<p>The category list view supports only a few specific sorting options:</p>
+<ul>
+  <li>id -- The category id.</li>
+  <li><strong>name</strong> -- The category name.</li>
 </ul>';
 $lang['param_sorttype'] = 'Denne parameteren er kun gyldig for standard samemndragsvisningen, hvor denne parameteren benyttes til &aring; konvertere verdiene til en annen type s&aring; de kan benyttes til sortering. Gyldige verdier er STRING,SIGNED og UNSIGNED. Om dette ikke er satt her s&aring; vil standardtypen STRING bli benyttet.';
 $lang['param_summarypage'] = 'Denne parameter er kun aktuell for action=hierarchy, hvor den tillater &aring; spesifisere en sideID eller alias som vil bli benyttet for alle lenker for sammendragsvisning';
@@ -337,6 +342,7 @@ $lang['prompt_notfound_msg'] = 'Feilmelding for n&aring;r et produkt ikke blir f
 $lang['prompt_notfound_page'] = 'Side &aring; omdirigere til permanent?';
 $lang['prompt_prod_detailpage'] = 'Standardside for Product detaljvisning';
 $lang['prompt_products_matching'] = 'Produkter som passer %s';
+$lang['prompt_summarypagelimit'] = 'Standard sidegrense i sammendragsmodus';
 $lang['prompt_summarysortorder'] = 'Standard sortering i sammendragsmodus';
 $lang['prompt_summarysorting'] = 'Standard sorteringsfelt i sammendragsmodus';
 $lang['prompt_template'] = 'Malkilde';
@@ -398,9 +404,9 @@ $lang['viewable_fields'] = 'Velg brukerdefinerte felter som skal vises i tabelle
 $lang['watermark_location'] = 'Vannmerke lokasjon';
 $lang['weight'] = 'Vekt';
 $lang['yes'] = 'Ja';
-$lang['utmz'] = '156861353.1274726983.2794.62.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/view/4955';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1276974234.1276983209.2902';
+$lang['utmz'] = '156861353.1288991067.3364.78.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/about-link/special-fans-listing/|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1290034209.1290107730.3395';
 $lang['qca'] = '1210971690-27308073-81952832';
+$lang['utmb'] = '156861353.1.10.1290107730';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1276983209';
 ?>
\ No newline at end of file
